@@ -3,8 +3,10 @@ from django.conf.urls.defaults import *
 from django.views.generic.simple import direct_to_template
 
 # lfs imports
-from lfs.core.sitemap import ProductSitemap
 from lfs.core.sitemap import CategorySitemap
+from lfs.core.sitemap import PageSitemap
+from lfs.core.sitemap import ProductSitemap
+from lfs.core.sitemap import ShopSitemap
 from lfs.core.views import one_time_setup
 
 # Robots
@@ -14,7 +16,7 @@ urlpatterns = patterns('django.views.generic.simple',
 
 # Sitemaps
 urlpatterns += patterns("django.contrib.sitemaps.views",
-    url(r'^sitemap.xml$', 'sitemap', {'sitemaps': {"products": ProductSitemap, "categories": CategorySitemap}})
+    url(r'^sitemap.xml$', 'sitemap', {'sitemaps': {"products": ProductSitemap, "categories": CategorySitemap, "pages": PageSitemap, "shop": ShopSitemap}})
 )
 
 # Shop
@@ -102,16 +104,6 @@ urlpatterns += patterns('',
     (r'^tagging/', include('lfs.tagging.urls')),
 )
 
-# Catalog REST API
-urlpatterns += patterns('',
-    (r'^catalog/api/', include('lfs.catalog.api.urls')),
-)
-
-# Manage REST API
-urlpatterns += patterns('',
-    (r'^manage/api/', include('lfs.manage.api.urls')),
-)
-
 urlpatterns += patterns('',
     (r'', include('lfs_contact.urls')),
 )
